Struct libpulse_simple_binding::Simple [−][src]
pub struct Simple { /* fields omitted */ }Expand description
An opaque simple connection object.
Implementations
Creates a new connection to the server.
Params
server: Server name, orNonefor default.name: A descriptive name for this client (application name, …).dir: Open this stream for recording or playback?dev: Sink (resp. source) name, orNonefor default.stream_name: A descriptive name for this stream (application name, song title, …).ss: The sample type to use.map: The channel map to use, orNonefor default.attr: Buffering attributes, orNonefor default.
Waits until all data already written is played by the daemon.
Reads some data from the server.
This function blocks until data.len() amount of data has been received from the server,
or until an error occurs.
Gets the playback or record latency.